#
# spec file for package pdftk
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           pdftk
Version:        1.44
Release:        10.1
License:        GPL-2.0+
Summary:        A handy tool for manipulating PDF
Url:            http://www.pdflabs.com/
Group:          Productivity/Publishing/PDF
Source0:        %{name}-%{version}-src.zip
Source1:        Makefile.SUSE
Patch0:         bug-427046_pdftk.cc.patch
AutoReqProv:    on
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  unzip

# BuildRequires package version suffix : "41" for "gcc41-java"
%define pkgv %nil
# gcc/gcj binaries version suffix : "-4.1" for "gcj-4.1"
%define gxxv %nil
# ligcj.jar version suffix : "-4.1" for "/usr/share/java/libgcj-4.1.jar"
%define jarv %nil

%if 0%{?suse_version} > 1140
%define jarv -4.6
%endif

%if 0%{?suse_version} <= 1140
%define jarv -4.5
%endif

%if 0%{?suse_version} <= 1120
%define jarv -4.4
%endif

%if 0%{?suse_version} <= 1110
%define jarv -4.3
%endif

# openSUSE 11.0 and SLE_11 are odd cases.
# %jarv is still correct from above for both
%if 0%{?suse_version} == 1100 || 0%{?sles_version} == 11
# "Nothing provides libgcj"
%define pkgv 43
# "gcj command not found", "gcjh command not found"
%define gxxv -4.3
%endif

%if 0%{?suse_version} == 1020
%define jarv -4.1.2
%endif

%if 0%{?suse_version} == 1010
%define jarv -4.1.0
%endif

%if 0%{?suse_version} == 1000
%define jarv -4.0.2
%endif

BuildRequires:  gcc%{pkgv}-c++ gcc%{pkgv}-java libgcj%{pkgv} libgcj%{pkgv}-devel

%if 0%{?suse_version} > 1010 || 0%{?sles_version} == 10
BuildRequires:  fastjar
%endif

%description
If PDF is electronic paper, then pdftk is an electronic staple-remover,
hole-punch, binder, secret-decoder-ring, and X-Ray-glasses.
Pdftk is a simple tool for doing everyday things with PDF documents.

Use it to:
  * Merge PDF Documents
  * Split PDF Pages into a New Document
  * Rotate PDF Documents or Pages
  * Decrypt Input as Necessary (Password Required)
  * Encrypt Output as Desired
  * Fill PDF Forms with X/FDF Data and/or Flatten Forms
  * Generate FDF Data Stencil from PDF Forms
  * Apply a Background Watermark or a Foreground Stamp
  * Report PDF Metrics such as Metadata and Bookmarks
  * Update PDF Metadata
  * Attach Files to PDF Pages or the PDF Document
  * Unpack PDF Attachments
  * Burst a PDF Document into Single Pages
  * Uncompress and Re-Compress Page Streams
  * Repair Corrupted PDF (Where Possible)

%prep
%setup -q -n %{name}-%{version}-dist
%patch0 -p1
%__cp %{S:1} pdftk/Makefile
%__sed -i 's/\r$//' changelog.txt license_gpl_pdftk/*.txt license_gpl_pdftk/*/*.txt

%build
%__make -C pdftk CXXFLAGS="%optflags" LIBGCJ=%{_javadir}/libgcj%{jarv}.jar GXXV=%gxxv
%__strip pdftk/%name

%install
%__install -Dm 0755 pdftk/%name %{buildroot}%{_bindir}/%name
%__install -Dpm 0644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

%clean
%__rm -rf %buildroot

%files
%defattr(-,root,root)
%{_bindir}/%name
%{_mandir}/man1/%{name}.*
%doc changelog.txt license_gpl_pdftk/*.txt license_gpl_pdftk/*/*.txt

%changelog
* Wed May 18 2011 seife+obs@b1-systems.com
- fix build for FACTORY's gcc-4.6 (just increase version in spec)
* Thu Mar 17 2011 brian@aljex.com
- created new spec and makefile that builds on a wide range of SUSE versions (at least 10.0 to current)
- use the native/highest version of gcc/gcj on each version of SUSE, not forcing gcj41
- removed unnecessary dos2unix
- use rpm macros where possible
- created Makefile.SUSE
  allow for inconsistent names of executables and libgcj.jar
  allow rpm to supply %%%%optflags
  remove unrecognized -Wextra
  fastjar has no suffix on any version of SUSE
  un-hardcode "/usr/share/java", get from rpm macro(s) instead.
  allow using "make -f Makefile.SUSE VERSUFF=-4.5", so Makefile.SUSE
  can also be used manually following the same directions found in the source
  for the other makefiles.
* Tue Mar  8 2011 seife+obs@b1-systems.com
- use my original -p1 patch for bnc#427046
* Fri Jan 21 2011 mrdocs@opensuse.org
- update to version 1.44
- run spec-file cleaner
  o Added new feature for collating PDF page scans: shuffle. Please see
  the man page for usage details.
  o Introduced update_info_utf8, dump_data_utf8 and
    dump_data_fields_utf8 to provide UTF-8 companions to update_info,
    dump_data and dump_data_fields. These latter operations use XML
    numerical entities to encode non-ASCII characters. In version 1.43,
    we changed the encoding for update_info to UTF-8, but that made it
    incompatible with dump_data and also broke some downstream
    applications. By introducing these UTF-8 operations, we can revert
    update_info to its original behavior.
  o Burst feature now copies the metadata (including XMP) from the
    input file to the output pages.
  o Updated Bouncy Castle library to 1.45.
  o Removed or replaced third-party code that wasn't compatible with
    pdftk's GPL license.
  o Updated third-party license information.
* Tue Oct 26 2010 seife@opensuse.org
- update to version 1.43:
  o Improved input handle detection to reduce false hits.
  o Improved keyword detection logic to eliminate false hits if
    filenames happen to include pdftk keywords even, odd and end
  o Added option of prompting the user for the output when bursting
    a PDF. Also reviewed other filename prompting code.
  o Changed the PDF parser to accept name tokens longer than 127
    characters - the PDF Specification says that 127 is the limit.
    This isn't related to file names. The issue arose with PDFs
    created by Acrobat Web Capture 9.0.
  o Fixed a problem with filling form choice fields in some PDFs
    where the old form value was 'sticking.'
  o Changed pdftk behavior when handling subset fonts so it doesn't
    alter font name "tags." This was causing printing problems
    with Acrobat 3.01 on Windows.
  o Fixed a stream parsing bug that was causing page content to
    disappear after merge of PDFs generated by Microsoft Reporting
    Services PDF Rendering Extension 10.0.0.0.
  o Added multistamp and multibackground features provided by a
    Debian patch - thanks!
  o Clear the signal mask as workaround to environments that turn
    off signals before calling pdftk. This problem is known to
    cause pdftk hangs in some Python web setups as well as in PHP.
  o Set locale to C as workaround to an unusual exception. This is
    a Debian_patch. Please let me know if it causes any troubles.
  o Improved reporting of output errors via Debian patch
  o Added support for UTF-8 data in update_info via Debian patch
  o Added support for UTF-8 filenames via Debian patch
  o Updated build procedure to work better with newer versions of
    GCC. Maintained compatibility with older versions of GCC.
  o Added license information to the source tree for the third-
    party libraries that pdftk uses.
- removed obsolete patches
- small specfile cleanup
* Mon Oct 27 2008 ro@suse.de
- fix patch to apply (directory depth)
* Sun Oct 26 2008 bwalle@suse.de
- Add another JvInitClass() to last patch.
* Mon Oct 13 2008 toms@suse.de
- Integrated patch bnc#427046 from Bernhard Walle. Thanks, Bernhard!
* Mon Jan 14 2008 ro@suse.de
- took some of the current debian patch to make it build
* Tue Aug 21 2007 toms@suse.de
- Removed java_libs/com/lowagie/text/pdf/HyphenationAuto.java
  due to licensing issues
* Fri Aug 17 2007 toms@suse.de
- Removed pdftk-1.41/java_libs/com/lowagie/text/pdf/codec/postscript/
  due to licensing issues
* Fri Aug  3 2007 bwalle@suse.de
- update to 1.41 (#294793)
  o changes from 1.40 to 1.41
    · Fixed a bug that corrupted output PDF xref tables.
    · Fixed a bug that prevented XFDF form data from being passed
    to pdftk via stdin.
  o changes from 1.12 to 1.40
    · Added the stamp operation
    · Added the page rotating patch
    · Added the generate_fdf patch
    · The fill_form operation can now take XFDF data as well as FDF
    data.
    · Added the drop_xfa option
    · Added the keep_first_id and keep_final_id options
    · Upgraded the iText library
    · Added the -O2 optimizing switch to Makefile
    · Fixed a bug that caused pdftk to create bloated PDFs when
    input PDF pages had links on their pages.
    · Added License-Adobe.txt to the fonts folder
- fix line endings in pdftk.1.notes (rpmlint)
* Wed Jun 27 2007 rguenther@suse.de
- remove libgcj requires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Mon Aug 22 2005 skh@suse.de
- Fix build.
* Wed Jan 26 2005 ke@suse.de
- New package proposed by Thomas Schraitle; version 1.12.
